#
# spec file for package nmh
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nmh
BuildRequires:  gdbm-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  postfix
Requires:       less
Requires:       smtp_daemon
Provides:       mh
Obsoletes:      mh <= 6.8.4
Version:        1.7.1
Release:        1.19
Summary:        Unix Mail Handler
License:        BSD-3-Clause
Group:          Productivity/Networking/Email/Clients
Url:            https://www.nongnu.org/nmh/
Source0:        https://download.savannah.nongnu.org/releases/nmh/%{name}-%{version}.tar.gz
Source1:        https://download.savannah.nongnu.org/releases/nmh/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM bmwiedemann https://savannah.nongnu.org/support/?109535
Patch0:         reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
nmh (new MH) is a powerful electronic mail handling system. It was
originally based on version 6.8.3 of the MH message system developed by
the RAND Corporation and the University of California. It is intended
to be a (mostly) compatible drop-in replacement for MH.

nmh consists of a collection of fairly simple single-purpose programs
to send, receive, save, retrieve, and manipulate e-mail messages.
Because nmh is a suite rather than a single monolithic program, you may
freely intersperse nmh commands with other commands at your shell
prompt or write custom scripts that use these commands in flexible
ways.

%prep
%setup -q
%patch0 -p1

%build
export HOSTNAME=OBS # for boo#1084909
%configure  --libdir=%{_libexecdir}/%name \
            --docdir=%_defaultdocdir/%name \
            --sysconfdir=%{_sysconfdir}/nmh \
	        --enable-pop \
            --with-pager=/usr/bin/less
make

%install
make DESTDIR=$RPM_BUILD_ROOT install 

%files
%defattr(-,root,root)
%{_bindir}/*
%{_libexecdir}/%name
%dir %{_sysconfdir}/nmh
%config %{_sysconfdir}/nmh/*
%{_mandir}/man*/*
%_defaultdocdir/%name

%changelog
* Mon Jul 23 2018 bwiedemann@suse.com
- Update to version 1.7.1
- Add reproducible.patch to fix build date and hostname
  (boo#1047218, boo#1084909)
- Complete unification of network security support.  All network protocols
  have been refactored to use a common set of security routines.
  This means all protocols support all SASL mechanisms and TLS.
  TLS support has been strengthened to perform certificate name validation
  and to require TLS 1.1 as a minimum protocol.
  Also, all protocols can make use of the OAuth2/XOAUTH SASL mechanism,
  which is supported by Gmail.
- send(1) now supports adding switches to post(8) based on the address or
  domain of the email address in the From: header; this more easily allows
  users to support multiple identities.
- A generic facility for passing arguments to filter programs in repl(1)
  by use of the -convertargs switch.
- Native support for the manipulation of iCalendar requests; see mhical(1)
  for more details.
- See NEWS file for more changes
* Fri Mar  6 2015 p.drouand@gmail.com
- Update to version 1.6
  * The NEWS file contains an increased number of changes; please
    read it for news
- Update home Url to point Savannah's project page
- Use download Url as source
- Remove depreciated AUTHORS section
* Tue Oct 22 2013 max@suse.com
- New version 1.5:
  * comp, forw, and dist now process all drafts through
    mh-format(5) and now support new command line arguments -from,
  - to, -cc, -fcc, and -subject.
  * Nmh's idea of the local mailbox is now configurable via a new
    profile entry, Local-Mailbox.
  * post now requires a “From:” header in all message that it
    processes. All components files have been adjusted to include
    an appropriate “From:” header by default. The release notes
    have more information on how this transition will affect
    users.
  * The -attach option is now the default for send (using the
    header Nmh-Attachment) and -attachformat 1 is the default
    attachment type.
  * Command editing and filename completion (via readline) is now
    available in whatnow
  * Support for using an external command to filter the body of a
    message through in mhl. See mhl(1) for more details,
    specifically the format keyword, the formatproc entry in
    mh-profile(5), and the -fmtproc switch for mhl and repl.
  * Preliminary support for improved MIME handling when replying
    to messages. Yes, a long requested feature has a solution. See
    the release notes and docs/contrib/replyfilter for more
    information.
- Obsoletes nmh-warnings.patch
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Sep  8 2008 max@suse.de
- Bugfix release: 1.3
- Obsoletes nmh-64bit.patch and nmh-strcasecmp.patch .
- For more details, see /usr/share/doc/packages/nmh/ChangeLog .
* Tue Jul 15 2008 max@suse.de
- Adopted two patches from Debian to fix a segfault and several
  64bit problems (bnc#334176, bnc#347684).
* Mon Jul  2 2007 max@suse.de
- Mark /etc/nmh/* as config files (#285015).
* Wed Mar 28 2007 max@suse.de
- Update to version 1.2, which fixes a crash (#230763) and a
  performance problem (#230764).
- Fixed several compiler warnings (#232416).
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel and ncurses-devel BuildRequires
* Fri Jan 26 2007 ro@suse.de
- silence a compiler warning
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct  3 2005 mmj@suse.de
- Update to RC4
* Fri Jun 10 2005 meissner@suse.de
- Use RPM_OPT_FLAGS.
* Tue Jul  6 2004 mmj@suse.de
- Install libexec helper binaries in /usr/lib/nmh [#42774]
* Fri Mar 26 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
* Tue Feb 11 2003 mmj@suse.de
- Obsoletes and Provides mh -- not conflicts.
* Tue Jan 21 2003 meissner@suse.de
- make it build on ppc64.
* Thu Nov 28 2002 mmj@suse.de
- Update to 1.1-RC1
- Use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Apr 16 2002 mmj@suse.de
- Fix it correctly.
* Mon Apr 15 2002 mmj@suse.de
- Fixed specfile to own /etc/nmh
* Mon Jul 16 2001 mmj@suse.de
- Initial package. Hopefully Maddog is happy now :)
